@@ -11,6 +11,7 @@
 # This script was created with the virtualenv_install script.
 #
 
+import commands
 import re
 import urllib2
 import zipfile
@@ -22,6 +23,8 @@ import glob
 import errno
 import stat
 
+using_subversion = True
+
 #
 # The following taken from PyUtilib
 #
@@ -96,13 +99,28 @@ def parse_version(s):
 #   8.28.rc1
 #
 def guess_release(svndir):
-    output = urllib2.urlopen(svndir).read()
-    if output=="":
-       return None
-    links = re.findall('\<li>\<a href[^>]+>[^\<]+\</a>',output)
-    versions = []
-    for link in links:
-        versions.append( re.split('>', link[:-5])[-1] )
+    if using_subversion:
+        output = commands.getoutput('svn ls '+svndir)
+        if output=="":
+            return None
+        #print output
+        versions = []
+        for link in re.split('/',output.strip()):
+            tmp = link.strip()
+            if tmp != '':
+                versions.append( tmp )
+        #print versions
+    else:
+        if sys.version_info[:2] <= (2,5):
+            output = urllib2.urlopen(svndir).read()
+        else:
+            output = urllib2.urlopen(svndir, timeout=30).read()
+        if output=="":
+            return None
+        links = re.findall('\<li>\<a href[^>]+>[^\<]+\</a>',output)
+        versions = []
+        for link in links:
+            versions.append( re.split('>', link[:-5])[-1] )
     latest = None
     latest_str = None
     for version in versions:
@@ -223,6 +241,13 @@ class Repository(object):
 
     def guess_versions(self, offline=False):
         if not self.config.root is None:
+            if using_subversion:
+                rootdir_output = commands.getoutput('svn ls ' + self.config.root)
+            else:
+                if sys.version_info[:2] <= (2,5):
+                    rootdir_output = urllib2.urlopen(self.config.root).read()
+                else:
+                    rootdir_output = urllib2.urlopen(self.config.root, timeout=30).read()
             try:
                 self.trunk = self.config.root+'/trunk'
                 self.trunk_root = self.trunk
@@ -230,7 +255,7 @@ class Repository(object):
                 self.trunk = None
                 self.trunk_root = None
             try:
-                if offline:
+                if offline or not 'stable' in rootdir_output:
                     raise IOError
                 self.stable = guess_release(self.config.root+'/stable')
                 self.stable_root = self.stable
@@ -238,14 +263,14 @@ class Repository(object):
                 self.stable = None
                 self.stable_root = None
             try:
-                if offline:
+                if offline or not 'releases' in rootdir_output:
                     raise IOError
                 self.release = guess_release(self.config.root+'/releases')
                 self.tag = None
                 self.release_root = self.release
             except (urllib2.HTTPError,IOError):
                 try:
-                    if offline:
+                    if offline or not 'tags' in rootdir_output:
                         raise IOError
                     self.release = guess_release(self.config.root+'/tags')
                     self.tag = self.release
@@ -477,17 +502,17 @@ class Repository(object):
                 if offline:
                     self.run([self.python, 'setup.py', 'install'], dir=dir)
                 else:
-                    self.run([self.easy_install_path, '-q', self.pypi])
+                    self.run([self.python, self.easy_install_path, '-q', self.pypi])
             elif preinstall: 
                 if not os.path.exists(dir):
-                    self.run([self.easy_install_path, '-q', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
+                    self.run([self.python, self.easy_install_path, '-q', '--editable', '--build-directory', '.', self.pypi], dir=os.path.dirname(dir))
         except OSError, err:
             print "-----------------------------------------------------------------"
             print "Warning!!! Ignoring easy_install error '%s'" % str(err)
             print "-----------------------------------------------------------------"
 
     def easy_upgrade(self):
-        self.run([self.easy_install_path, '-q', '--upgrade', self.pypi])
+        self.run([self.python, self.easy_install_path, '-q', '--upgrade', self.pypi])
 
     def run(self, cmd, dir=None):
         cwd=os.getcwd()
@@ -501,8 +526,9 @@ class Repository(object):
 
 
 if sys.platform.startswith('win'):
-   Repository.python += '.exe'
-   Repository.svn += '.exe'
+    if not is_jython:
+        Repository.python += '.exe'
+    Repository.svn += '.exe'
 
 
 def filter_python_develop(line):
@@ -638,15 +664,15 @@ class Installer(object):
             default=True)
 
         parser.add_option('--config',
-            help='Add INI config files that specify the packages used in this installation. ',
+            help='Use an INI config file to specify the packages used in this installation.  Using this option clears the initial configuration, but multiple uses of this option will add package specifications.',
             action='append',
             dest='config_files',
             default=[])
 
-        parser.add_option('--clear-config',
-            help='Clear any initial configuration data that was specified when constructing this installer.',
+        parser.add_option('--keep-config',
+            help='Keep the initial configuration data that was specified if the --config option is specified.',
             action='store_true',
-            dest='clear_config',
+            dest='keep_config',
             default=False)
 
         parser.add_option('--localize',
@@ -693,8 +719,8 @@ class Installer(object):
         if options.update and len(options.config_files) > 0:
             self.logger.fatal("ERROR: cannot specify --config when specifying the --update option.")
             sys.exit(1000)
-        if options.update and options.clear_config:
-            self.logger.fatal("ERROR: cannot specify --clear-config when specifying the --update option.")
+        if options.update and options.keep_config:
+            self.logger.fatal("ERROR: cannot specify --keep-config when specifying the --update option.")
             sys.exit(1000)
         if len(args) > 1:
             self.logger.fatal("ERROR: installer script can only have one argument")
@@ -717,11 +743,11 @@ class Installer(object):
         if options.update:
             self.config=None
             options.config_files.append( join(self.abshome_dir, 'admin', 'config.ini') )
-        if not self.config is None and not options.clear_config:
+        if not self.config is None and (len(options.config_files) == 0 or options.keep_config):
             fp = StringIO.StringIO(self.config)
             self.read_config_file(fp=fp)
             fp.close()
-        if not self.config_file is None and not options.clear_config:
+        if not self.config_file is None and (len(options.config_files) == 0 or options.keep_config):
             self.read_config_file(file=self.config_file)
         for file in options.config_files:
             self.read_config_file(file=file)
@@ -937,7 +963,10 @@ class Installer(object):
         else:
             bindir = join(self.abshome_dir,"bin")
         Repository.easy_install_path = os.path.abspath(join(bindir, 'easy_install'))
-        Repository.python = os.path.abspath(join(bindir, 'python'))
+        if is_jython:
+            Repository.python = os.path.abspath(join(bindir, 'jython.bat'))
+        else:
+            Repository.python = os.path.abspath(join(bindir, 'python'))
         #
         # Install the related packages
         #
@@ -1024,8 +1053,13 @@ class Installer(object):
         if not fp is None:
             parser.readfp(fp, '<default configuration>')
         elif not os.path.exists(file):
+            if not '/' in file and not self.config_file is None:
+                file = os.path.dirname(self.config_file)+"/"+file
             try:
-                output = urllib2.urlopen(file).read()
+                if sys.version_info[:2] <= (2,5):
+                    output = urllib2.urlopen(file).read()
+                else:
+                    output = urllib2.urlopen(file, timeout=30).read()
             except Exception, err:
                 print "Problems opening configuration url:",file
                 raise
